@@ -24,7 +24,7 @@ use constant EMAIL_ATTRIBUTES => (
     encoding     => 'quoted-printable',
 );
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub new
 {
@@ -262,19 +262,20 @@ sub _load_commits
             push @commits, [ $time, $id ];
         }
     }
+    close $fh;
 
     return @commits;
 }
 
 sub _make_email_mime
 {
-    my ($ft, $filename) = @_;
+    my ($content, $filename) = @_;
 
     return
         Email::MIME->create(
             attributes => { EMAIL_ATTRIBUTES,
                             filename => $filename },
-            body_str   => slurp($ft)
+            body_str   => $content
         );
 }
 
@@ -282,21 +283,17 @@ sub get_email
 {
     my ($self, $from, $to) = @_;
 
-    my $config = $self->{'config'};
-
-    my ($repo_path, $db_path, $repositories) =
-        @{$config}{qw(repository_path db_path repositories)};
-
     ($from, $to) = $self->_process_bounds($from, $to);
 
     my $output_ft = File::Temp->new();
     my @commit_data;
 
-    for my $repository (@{$repositories}) {
+    $self->_repository_map(sub {
+        my ($repo_path, $db_path, $repository) = @_;
         chdir $repo_path;
         my ($name, $impl) = _load_and_open_repository($repository);
         if (not $impl->is_usable()) {
-            next;
+            return;
         }
         my $current_branch = $impl->branch_name();
 
@@ -318,16 +315,13 @@ sub get_email
                                  (join '', @{$impl->show($id)}).
                                  "\n";
 
-                my $att_ft = File::Temp->new();
-                print $att_ft @{$impl->show_all($id)};
-                $att_ft->flush();
-
-                push @commit_data, [$name, $branch_name, $id, $att_ft];
+                my $content = join '', @{$impl->show_all($id)};
+                push @commit_data, [$name, $branch_name, $id, $content];
             }
             print $output_ft "\n";
         }
         $impl->checkout($current_branch);
-    }
+    });
 
     $output_ft->flush();
 
@@ -335,13 +329,14 @@ sub get_email
         return;
     }
 
+    my $config = $self->{'config'};
     my $email = Email::MIME->create(
         header_str => [ %{$config->{'headers'} || {}} ],
         parts => [
-            _make_email_mime($output_ft, 'log.txt'),
+            _make_email_mime(slurp($output_ft), 'log.txt'),
             map {
-                my ($name, $branch_name, $id, $att_ft) = @{$_};
-                _make_email_mime($att_ft,
+                my ($name, $branch_name, $id, $content) = @{$_};
+                _make_email_mime($content,
                                  "$name-$branch_name-$id.diff"),
             } @commit_data
         ]
@@ -362,7 +357,7 @@ App::SCM::Digest
 
     my $digest = App::SCM::Digest->new($config);
     $digest->update();
-    $digest->send();
+    $digest->get_email();
 
 =head1 DESCRIPTION
 
